pub type ObjectiveResult = Result<f64, ObjectiveError>;Expand description
The value an objective closure returns for one trial.
Aliased Type
pub enum ObjectiveResult {
Ok(f64),
Err(ObjectiveError),
}pub type ObjectiveResult = Result<f64, ObjectiveError>;The value an objective closure returns for one trial.
pub enum ObjectiveResult {
Ok(f64),
Err(ObjectiveError),
}